==> nextcloud-32.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/sv.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU-info inte tillgänglig",
    "CPU Usage:" : "CPU-användning:",
    "Load average: {percentage} % ({load}) last minute" : "Genomsnittlig belastning: {percentage} % ({load}) senaste minuten",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) senaste minuten\n{last5MinutesPercentage} % ({last5Minutes}) senaste 5 minuterna\n{last15MinutesPercentage} % ({last15Minutes}) senaste 15 minuterna",
    "RAM Usage:" : "RAM-användning:",
    "SWAP Usage:" : "SWAP-användning:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Totalt: {memTotalBytes}/Nuvarande användning: {memUsageBytes}",
    "RAM info not available" : "RAM info inte tillgängligt",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totalt: {swapTotalBytes}/Nuvarande användning: {swapUsageBytes}",
    "SWAP info not available" : "SWAP info inte tillgängligt",
    "Copied!" : "Kopierad!",
    "Not supported!" : "Stöds inte!",
    "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
    "Press Ctrl-C to copy." : "Tryck Ctrl-C för att kopiera.",
    "System" : "System",
    "Monitoring" : "Övervakning",
    "Monitoring app with useful server information" : "Övervaknings-app med användbar serverinformation",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Ger användbar serverinformation, såsom CPU belastning, RAM-användning, diskanvändning, antal användare, m.m.",
    "Operating System:" : "Operativsystem:",
    "CPU:" : "CPU:",
    "threads" : "trådar",
    "Memory:" : "Minne:",
    "Server time:" : "Servertid:",
    "Uptime:" : "Upptid:",
    "Temperature" : "Temperatur",
    "Load" : "Last",
    "Memory" : "Minne",
    "Disk" : "Lagring",
    "Mount:" : "Montering:",
    "Filesystem:" : "Filsystem:",
    "Size:" : "Storlek:",
    "Available:" : "Tillgängligt:",
    "Used:" : "Använt:",
    "Files:" : "Filer:",
    "Storages:" : "Lagring:",
    "Free Space:" : "Ledigt utrymme:",
    "Network" : "Nätverk",
    "Hostname:" : "Värdnamn:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Hastighet:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktiva användare",
    "Last hour" : "Senaste timmen",
    "%s%% of all users" : "%s%% av alla användare",
    "Last 24 Hours" : "Senaste 24 timmarna",
    "Last 7 Days" : "Senaste 7 dagarna",
    "Last 30 Days" : "Senaste 30 dagarna",
    "Shares" : "Delningar",
    "Users:" : "Användare:",
    "Groups:" : "Grupper:",
    "Links:" : "Länkar:",
    "Emails:" : "E-post:",
    "Federated sent:" : "Federerat skickat:",
    "Federated received:" : "Federerat mottaget:",
    "Talk conversations:" : "Talk-konversationer:",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory limit:" : "Minnesgräns:",
    "Max execution time:" : "Max körningstid:",
    "Upload max size:" : "Största uppladdningsstorlek:",
    "OPcache Revalidate Frequency:" : "Frekvens för återvalidering av OPcache:",
    "Extensions:" : "Tillägg:",
    "Unable to list extensions" : "Det går inte att lista tillägg",
    "Show phpinfo" : "Visa phpinfo",
    "FPM worker pool" : "FPM-arbetspool",
    "Pool name:" : "Poolnamn:",
    "Pool type:" : "Pooltyp:",
    "Start time:" : "Starttid:",
    "Accepted connections:" : "Accepterade anslutningar:",
    "Total processes:" : "Totalt antal processer:",
    "Active processes:" : "Aktiva processer:",
    "Idle processes:" : "Inaktiva processer:",
    "Listen queue:" : "Lyssningskö:",
    "Slow requests:" : "Långsamma förfrågningar:",
    "Max listen queue:" : "Maximal lyssningskö:",
    "Max active processes:" : "Maximalt antal aktiva processer:",
    "Max children reached:" : "Maximalt antal underprocesser uppnått:",
    "Database" : "Databas",
    "Type:" : "Typ:",
    "External monitoring tool" : "Externt övervakningsverktyg",
    "Use this end point to connect an external monitoring tool:" : "Använd denna slutpunkt för att ansluta ett externt övervakningsverktyg:",
    "Copy" : "Kopiera",
    "Output in JSON" : "Utdata i JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Hoppa över appsektionen (inkludera appsektionen skickar en extern begäran till appbutiken)",
    "Skip server update" : "Hoppa över serveruppdatering",
    "To use an access token, please generate one then set it using the following command:" : "För att använda en access-token, generera en och ställ in den med följande kommando:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Skicka sedan token med \"NC-Token\"-header när du frågar efter ovanstående URL.",
    "Unknown Processor" : "Okänd processor"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/sv.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU-info inte tillgänglig",
    "CPU Usage:" : "CPU-användning:",
    "Load average: {percentage} % ({load}) last minute" : "Genomsnittlig belastning: {percentage} % ({load}) senaste minuten",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) senaste minuten\n{last5MinutesPercentage} % ({last5Minutes}) senaste 5 minuterna\n{last15MinutesPercentage} % ({last15Minutes}) senaste 15 minuterna",
    "RAM Usage:" : "RAM-användning:",
    "SWAP Usage:" : "SWAP-användning:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Totalt: {memTotalBytes}/Nuvarande användning: {memUsageBytes}",
    "RAM info not available" : "RAM info inte tillgängligt",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totalt: {swapTotalBytes}/Nuvarande användning: {swapUsageBytes}",
    "SWAP info not available" : "SWAP info inte tillgängligt",
    "Copied!" : "Kopierad!",
    "Not supported!" : "Stöds inte!",
    "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
    "Press Ctrl-C to copy." : "Tryck Ctrl-C för att kopiera.",
    "Unknown" : "Okänd",
    "%1$d days, %2$d hours, %3$d minutes, %4$d seconds" : "%1$d dagar, %2$d timmar, %3$d minuter, %4$d sekunder",
    "%1$d hours, %2$d minutes, %3$d seconds" : "%1$d timmar, %2$d minuter, %3$d sekunder",
    "System" : "System",
    "Monitoring" : "Övervakning",
    "Monitoring app with useful server information" : "Övervaknings-app med användbar serverinformation",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Ger användbar serverinformation, såsom CPU belastning, RAM-användning, diskanvändning, antal användare, m.m.",
    "Operating System:" : "Operativsystem:",
    "CPU:" : "CPU:",
    "threads" : "trådar",
    "Memory:" : "Minne:",
    "Server time:" : "Servertid:",
    "Uptime:" : "Upptid:",
    "Temperature" : "Temperatur",
    "Load" : "Last",
    "Memory" : "Minne",
    "Disk" : "Lagring",
    "Mount:" : "Montering:",
    "Filesystem:" : "Filsystem:",
    "Size:" : "Storlek:",
    "Available:" : "Tillgängligt:",
    "Used:" : "Använt:",
    "Files:" : "Filer:",
    "Storages:" : "Lagring:",
    "Free Space:" : "Ledigt utrymme:",
    "Network" : "Nätverk",
    "Hostname:" : "Värdnamn:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Hastighet:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktiva användare",
    "Last hour" : "Senaste timmen",
    "%s%% of all users" : "%s%% av alla användare",
    "Last 24 Hours" : "Senaste 24 timmarna",
    "Last 7 Days" : "Senaste 7 dagarna",
    "Last 30 Days" : "Senaste 30 dagarna",
    "Shares" : "Delningar",
    "Users:" : "Användare:",
    "Groups:" : "Grupper:",
    "Links:" : "Länkar:",
    "Emails:" : "E-post:",
    "Federated sent:" : "Federerat skickat:",
    "Federated received:" : "Federerat mottaget:",
    "Talk conversations:" : "Talk-konversationer:",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory limit:" : "Minnesgräns:",
    "MB" : "MB",
    "Max execution time:" : "Max körningstid:",
    "seconds" : "sekunder",
    "Upload max size:" : "Största uppladdningsstorlek:",
    "OPcache Revalidate Frequency:" : "Frekvens för återvalidering av OPcache:",
    "Extensions:" : "Tillägg:",
    "Unable to list extensions" : "Det går inte att lista tillägg",
    "PHP Info:" : "PHP Info:",
    "Show phpinfo" : "Visa phpinfo",
    "FPM worker pool" : "FPM-arbetspool",
    "Pool name:" : "Poolnamn:",
    "Pool type:" : "Pooltyp:",
    "Start time:" : "Starttid:",
    "Accepted connections:" : "Accepterade anslutningar:",
    "Total processes:" : "Totalt antal processer:",
    "Active processes:" : "Aktiva processer:",
    "Idle processes:" : "Inaktiva processer:",
    "Listen queue:" : "Lyssningskö:",
    "Slow requests:" : "Långsamma förfrågningar:",
    "Max listen queue:" : "Maximal lyssningskö:",
    "Max active processes:" : "Maximalt antal aktiva processer:",
    "Max children reached:" : "Maximalt antal underprocesser uppnått:",
    "Database" : "Databas",
    "Type:" : "Typ:",
    "External monitoring tool" : "Externt övervakningsverktyg",
    "Use this end point to connect an external monitoring tool:" : "Använd denna slutpunkt för att ansluta ett externt övervakningsverktyg:",
    "Copy" : "Kopiera",
    "Output in JSON" : "Utdata i JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Hoppa över appsektionen (inkludera appsektionen skickar en extern begäran till appbutiken)",
    "Skip server update" : "Hoppa över serveruppdatering",
    "To use an access token, please generate one then set it using the following command:" : "För att använda en access-token, generera en och ställ in den med följande kommando:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Skicka sedan token med \"NC-Token\"-header när du frågar efter ovanstående URL.",
    "Unknown Processor" : "Okänd processor"
},
"nplurals=2; plural=(n != 1);");
